@@ -1,3 +1,5 @@
+from typing import Any, cast, Dict, Optional, Union
+
 from gitlab import exceptions as exc
 from gitlab.base import RequiredOptional, RESTManager, RESTObject
 from gitlab.mixins import CreateMixin, CRUDMixin, ObjectDeleteMixin, SaveMixin
@@ -15,7 +17,7 @@ class GroupCluster(SaveMixin, ObjectDeleteMixin, RESTObject):
 
 
 class GroupClusterManager(CRUDMixin, RESTManager):
-    _path = "/groups/%(group_id)s/clusters"
+    _path = "/groups/{group_id}/clusters"
     _obj_cls = GroupCluster
     _from_parent_attrs = {"group_id": "id"}
     _create_attrs = RequiredOptional(
@@ -33,11 +35,13 @@ class GroupClusterManager(CRUDMixin, RESTManager):
     )
 
     @exc.on_http_error(exc.GitlabStopError)
-    def create(self, data, **kwargs):
+    def create(
+        self, data: Optional[Dict[str, Any]] = None, **kwargs: Any
+    ) -> GroupCluster:
         """Create a new object.
 
         Args:
-            data (dict): Parameters to send to the server to create the
+            data: Parameters to send to the server to create the
                          resource
             **kwargs: Extra options to send to the server (e.g. sudo or
                       'ref_name', 'stage', 'name', 'all')
@@ -47,11 +51,16 @@ class GroupClusterManager(CRUDMixin, RESTManager):
             GitlabCreateError: If the server cannot perform the request
 
         Returns:
-            RESTObject: A new instance of the manage object class build with
-                        the data sent by the server
+            A new instance of the manage object class build with
+                the data sent by the server
         """
-        path = "%s/user" % (self.path)
-        return CreateMixin.create(self, data, path=path, **kwargs)
+        path = f"{self.path}/user"
+        return cast(GroupCluster, CreateMixin.create(self, data, path=path, **kwargs))
+
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> GroupCluster:
+        return cast(GroupCluster, super().get(id=id, lazy=lazy, **kwargs))
 
 
 class ProjectCluster(SaveMixin, ObjectDeleteMixin, RESTObject):
@@ -59,7 +68,7 @@ class ProjectCluster(SaveMixin, ObjectDeleteMixin, RESTObject):
 
 
 class ProjectClusterManager(CRUDMixin, RESTManager):
-    _path = "/projects/%(project_id)s/clusters"
+    _path = "/projects/{project_id}/clusters"
     _obj_cls = ProjectCluster
     _from_parent_attrs = {"project_id": "id"}
     _create_attrs = RequiredOptional(
@@ -77,11 +86,13 @@ class ProjectClusterManager(CRUDMixin, RESTManager):
     )
 
     @exc.on_http_error(exc.GitlabStopError)
-    def create(self, data, **kwargs):
+    def create(
+        self, data: Optional[Dict[str, Any]] = None, **kwargs: Any
+    ) -> ProjectCluster:
         """Create a new object.
 
         Args:
-            data (dict): Parameters to send to the server to create the
+            data: Parameters to send to the server to create the
                          resource
             **kwargs: Extra options to send to the server (e.g. sudo or
                       'ref_name', 'stage', 'name', 'all')
@@ -91,8 +102,13 @@ class ProjectClusterManager(CRUDMixin, RESTManager):
             GitlabCreateError: If the server cannot perform the request
 
         Returns:
-            RESTObject: A new instance of the manage object class build with
-                        the data sent by the server
+            A new instance of the manage object class build with
+                the data sent by the server
         """
-        path = "%s/user" % (self.path)
-        return CreateMixin.create(self, data, path=path, **kwargs)
+        path = f"{self.path}/user"
+        return cast(ProjectCluster, CreateMixin.create(self, data, path=path, **kwargs))
+
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> ProjectCluster:
+        return cast(ProjectCluster, super().get(id=id, lazy=lazy, **kwargs))
